/****************************************************************************
** Meta object code from reading C++ file 'section.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plasma-desktop-6.6.5/kcms/keyboard/tastenbrett/section.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'section.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7SectionE_t {};
} // unnamed namespace

template <> constexpr inline auto Section::qt_create_metaobjectdata<qt_meta_tag_ZN7SectionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Section",
        "priority",
        "top",
        "left",
        "width",
        "height",
        "angle",
        "rows",
        "QList<QObject*>",
        "doodads"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'priority'
        QtMocHelpers::PropertyData<uchar>(1, QMetaType::UChar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'top'
        QtMocHelpers::PropertyData<short>(2, QMetaType::Short, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'left'
        QtMocHelpers::PropertyData<short>(3, QMetaType::Short, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'width'
        QtMocHelpers::PropertyData<ushort>(4, QMetaType::UShort, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'height'
        QtMocHelpers::PropertyData<ushort>(5, QMetaType::UShort, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'angle'
        QtMocHelpers::PropertyData<short>(6, QMetaType::Short, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rows'
        QtMocHelpers::PropertyData<QList<QObject*>>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'doodads'
        QtMocHelpers::PropertyData<QList<QObject*>>(9, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Section, qt_meta_tag_ZN7SectionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Section::staticMetaObject = { {
    QMetaObject::SuperData::link<XkbObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7SectionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7SectionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7SectionE_t>.metaTypes,
    nullptr
} };

void Section::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Section *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QObject*> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uchar*>(_v) = _t->auto_prop_priority(); break;
        case 1: *reinterpret_cast<short*>(_v) = _t->auto_prop_top(); break;
        case 2: *reinterpret_cast<short*>(_v) = _t->auto_prop_left(); break;
        case 3: *reinterpret_cast<ushort*>(_v) = _t->auto_prop_width(); break;
        case 4: *reinterpret_cast<ushort*>(_v) = _t->auto_prop_height(); break;
        case 5: *reinterpret_cast<short*>(_v) = _t->auto_prop_angle(); break;
        case 6: *reinterpret_cast<QList<QObject*>*>(_v) = _t->rows; break;
        case 7: *reinterpret_cast<QList<QObject*>*>(_v) = _t->doodads; break;
        default: break;
        }
    }
}

const QMetaObject *Section::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Section::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7SectionE_t>.strings))
        return static_cast<void*>(this);
    return XkbObject::qt_metacast(_clname);
}

int Section::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = XkbObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
